Development_Stack_Installation_Example_20160130_01

# Development Stack Installation¶

Written by Aric Sanders, 01/2016

## Git Installation¶

1. Download and install Git
   - Git is a version control program
   - Github and bitbucket are good places to put repositories

## Python Base Installation¶

1. Install Anaconda
   - Use the python 2.7 installer
   - This installs a large number of packages
   - Includes Jupyter, which is a mathematica style notebook for python.
   - A good overview of jupyter's capability can be found here
   - in ubuntu down load the Anaconda package, from the directory run bash Anaconda....sh
2. Install PyCharm, Communtity Edition is free
   - Pycharm is an IDE (Integrated Development Environment) for python
   - It integrates very well with git, and it includes very good tools for working with code, if you install git first it will autodetect it.
   - Requires OpenJDK to be installed. The ubuntu command is sudo apt-get install openjdk-7-jre or JRE ( Windows ) to be installed.

## Python Package Installation¶

### For python packages using pip¶

\$ pip install package, in ubuntu make sure you are a superuser, i.e. sudo

or in python code

    import os
        os.system(r'pip install pyvisa')

1. Install Pdoc
   - pdoc makes an html page given an import-able module
   - pdoc.html('os') or a text version pdoc.text('os')
2. Install NIVisa
   - NIVISA requires regstration but is free
   - It allows communication through several methods including GPIB
   - This is not a python package but you need it for pyvisa, pyvisa-py looks to be a potential alternative.
3. Install pyvisa
4. Install Django
5. Install WxPython, not pip but there are prebuilt binaries
6. Install odo, pip install has errors on ubuntu.
7. Install django-registration and change registration/forms.py to include first_name and last_name on the user form
   - at a command prompt: pip install django-registration
8. Install django-bootstrap-breadcrumbs
   - at a command prompt: pip install django-bootstrap-breadcrumbs
9. Install markdown
   - at a command prompt: pip install markdown

10. Install Boa Constructor for Wx FrontEnds creations

    - choose boa-constructor-0.6.1.src.zip from the download page, the binary installers do not work if python is installed under the anaconda directory

    - There some problems with the source code that must be fixed:

      - All references to wx.NO_3D must be removed (I commented them out)

        1. in prefs.rc.py
           - splitterStyle = wx.SP_LIVE_UPDATE | wx.SP_3DSASH
           - #removed option | wx.NO_3D,03/02/2016 Aric Sanders
        2. in enumerations.py
           - windowNameStyles
           - #removed the option 'wx.NO_3D':wx.NO_3D, 03/02/2016 Aric Sanders
           - windowStyles
           - #removed the window style wx.NO_3D, 03/02/2016 Aric Sanders
        3. in Inspector.py
           - self.categories
           - #removed the style wx.NO_3D | on 03/02/2016 Aric Sanders
        - Because you unzipped the file into something like C:\python27\Lib\site-packages\boa-constructor-0.6.1, you have to make a new folder Boa and add an init.py file to it.
        - Now there are a lot of things improperly namespaced assuming that you will add an enviornmental variable to help it out. I renamspaced them to Boa.

## Inkscape Installation¶

1. Download and install Inkscape
   - Inkscape is a svg (scalable vector graphics) editor
   - In ubuntu use sudo apt-get install inkscape at a terminal

## Open Office Installation¶

1. Download and install open office
   - Open office can be scripted through pyuno to convert many formats
   - This is really optional, any office suite with html conversion will work
   - Ultimately the idea is to use unoconv